@@ -96,7 +96,7 @@ public:
         AbstractDataSource(nullptr)
     {}
     ~TestDataSource() {
-        emit aboutToBeDestroyed();
+        Q_EMIT aboutToBeDestroyed();
     }
     void requestData(const QString &mimeType, qint32 fd) override {
         Q_UNUSED(mimeType);
@@ -150,7 +150,6 @@ void DataControlInterfaceTest::init()
     QVERIFY(m_display->isRunning());
 
     m_seat = new SeatInterface(m_display, this);
-    m_seat->create();
     m_serverCompositor = new CompositorInterface(m_display, this);
     m_dataControlDeviceManagerInterface = new DataControlDeviceManagerV1Interface(m_display, this);
 
