@@ -4,8 +4,7 @@
 
     SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
-#ifndef WAYLAND_SERVER_LINUXDMABUF_INTERFACE_H
-#define WAYLAND_SERVER_LINUXDMABUF_INTERFACE_H
+#pragma once
 
 #include "global.h"
 #include "resource.h"
@@ -77,10 +76,12 @@ class KWAYLANDSERVER_EXPORT LinuxDmabufUnstableV1Interface : public Global
 {
     Q_OBJECT
 public:
+    explicit LinuxDmabufUnstableV1Interface(Display *display, QObject *parent = nullptr);
+
     enum Flag {
         YInverted           = (1 << 0),    /// Contents are y-inverted
         Interlaced          = (1 << 1),    /// Content is interlaced
-        BottomFieldFirst    = (1 << 2)     /// Bottom field first
+        BottomFieldFirst    = (1 << 2),    /// Bottom field first
     };
 
     Q_DECLARE_FLAGS(Flags, Flag)
@@ -139,21 +140,15 @@ public:
 
     /**
      * Returns the LinuxDmabufInterface for the given resource.
-     **/
+     */
     static LinuxDmabufUnstableV1Interface *get(wl_resource *native);
 
 private:
-    /**
-     * @internal
-     */
-    explicit LinuxDmabufUnstableV1Interface(Display *display, QObject *parent = nullptr);
-
     /**
      * Returns a pointer to the wl_buffer implementation for imported dmabufs.
      */
     static const struct wl_buffer_interface *bufferImplementation();
 
-    friend class Display;
     friend class BufferInterface;
 
     class Private;
@@ -164,5 +159,3 @@ private:
 
 Q_DECLARE_METATYPE(KWaylandServer::LinuxDmabufUnstableV1Interface*)
 Q_DECLARE_OPERATORS_FOR_FLAGS(KWaylandServer::LinuxDmabufUnstableV1Interface::Flags)
-
-#endif // WAYLAND_SERVER_LINUXDMABUF_INTERFACE_H
